2024-07-12 Version: 1.0.2
- Update API UpdatePublicNetworkStatus: add param Cidr.


2024-06-25 Version: 1.0.1
- Update API GetInstanceDetail: update response param.
- Update API ListInstances: update response param.


2024-06-20 Version: 1.0.0
- Generated python 2023-10-12 for milvus.

